@@ -1,6 +1,5 @@
 from myst.client import Client
-
-from ...models.project_get import ProjectGet
+from myst.openapi.models.project_get import ProjectGet
 
 
 def request_sync(client: Client, uuid: str) -> ProjectGet:
