@@ -1,8 +1,7 @@
 from typing import Any, Dict, Optional
 
 from myst.client import Client
-
-from ...models.user_list import UserList
+from myst.openapi.models.user_list import UserList
 
 
 def request_sync(client: Client, organization_uuid: Optional[str] = None) -> UserList:
