@@ -1,4 +1,4 @@
-from typing import Any, List, Optional
+from typing import Any, Dict, List, Optional
 
 from pydantic import Field
 from typing_extensions import Literal
@@ -22,8 +22,8 @@ class ModelGet(base_model.BaseModel):
     creator: str
     deploy_status: DeployStatus
     connector_uuid: str
-    parameters: Any
-    input_specs_schema: Any
+    parameters: Dict[str, Any]
+    input_specs_schema: Dict[str, Any]
     update_time: Optional[str] = None
     description: Optional[str] = None
     output_specs: Optional[List[TimeDatasetSpec]] = None
